==> automonisaur-0.3.18-py3-none-any.whl: automon/integrations/nmap/client.py <==
import os

from automon.log import logger
from automon.helpers import Run
from automon.helpers.dates import Dates

from .config import NmapConfig
from .output import NmapResult

log = logger.logging.getLogger(__name__)
log.setLevel(logger.INFO)


class Nmap(object):
    def __init__(self, command: str = None, config: NmapConfig = None, *args, **kwargs):
        self._runner = Run()

        self.config = config or NmapConfig()
        self.output_file = f'nmap-{Dates.filename_timestamp()}.xml'

        self.result = None
        self.command = str()
        self.error = bytes()

        self._stdout = None
        self._stderr = None
        self._returncode = None

        if command:
            self.run(command=command, *args, **kwargs)

    def __repr__(self):
        if self.result:
            return f'{self.command} ({round(len(self.result) / 1024, 2)} Kb)'
        if self.command:
            return f'{self.command}'
        if self.isReady():
            return f'Ready to scan'
        return f'Not able to scan'

    def __len__(self):
        if self.result:
            return len(self.result)
        return 0

    def isReady(self):
        return self.config.isReady()

    def nmap(self, command: str, **kwargs) -> bool:
        return self.run(command=command, **kwargs)

    def pretty(self):
        return print(self._runner.stdout.decode())

    def run(self, command: str, output: bool = True, cleanup: bool = True, **kwargs) -> bool:

        if not self.isReady():
            log.error(msg=f'nmap not found')
            return False

        nmap_command = f'{self.config.nmap} '

        if output:
            nmap_output = f'-oX {self.output_file}'
            nmap_command += f'{nmap_output} '

        nmap_command += f'{command}'

        log.info(f'running {nmap_command}')
        self._runner.run(nmap_command, **kwargs)
        log.debug(f'finished')

        self.command = nmap_command
        self._stdout = self._runner.stdout
        self._stderr = self._runner.stderr
        self._returncode = self._runner.returncode

        self.error = self._stderr

        if output:
            self.result = NmapResult(file=self.output_file, **kwargs)

            if cleanup:
                os.remove(self.output_file)
                log.info(f'deleted {self.output_file}')

        if self._stderr:
            log.error(msg=f'{self._stderr.decode()}')
            return False

        return True

    def scan(self, command: str, **kwargs) -> bool:
        return self.run(command=command, **kwargs)

==> automonisaur-0.4.1-py3-none-any.whl: automon/integrations/nmap/client.py <==
import os

from automon import log
from automon.helpers import Run
from automon.helpers.dates import Dates

from .config import NmapConfig
from .output import NmapResult

logger = log.logging.getLogger(__name__)
logger.setLevel(log.INFO)


class Nmap(object):
    def __init__(self, command: str = None, config: NmapConfig = None, *args, **kwargs):
        self._runner = Run()

        self.config = config or NmapConfig()
        self.output_file = f'nmap-{Dates.filename_timestamp()}.xml'

        self.result = None
        self.command = str()
        self.error = bytes()

        self._stdout = None
        self._stderr = None
        self._returncode = None

        if command:
            self.run(command=command, *args, **kwargs)

    def __repr__(self):
        if self.result:
            return f'{self.command} ({round(len(self.result) / 1024, 2)} Kb)'
        if self.command:
            return f'{self.command}'
        if self.isReady():
            return f'Ready to scan'
        return f'Not able to scan'

    def __len__(self):
        if self.result:
            return len(self.result)
        return 0

    def isReady(self):
        return self.config.isReady()

    def nmap(self, command: str, **kwargs) -> bool:
        return self.run(command=command, **kwargs)

    def pretty(self):
        return print(self._runner.stdout.decode())

    def run(self, command: str, output: bool = True, cleanup: bool = True, **kwargs) -> bool:

        if not self.isReady():
            logger.error(msg=f'nmap not found')
            return False

        nmap_command = f'{self.config.nmap} '

        if output:
            nmap_output = f'-oX {self.output_file}'
            nmap_command += f'{nmap_output} '

        nmap_command += f'{command}'

        logger.info(f'running {nmap_command}')
        self._runner.run(nmap_command, **kwargs)
        logger.debug(f'finished')

        self.command = nmap_command
        self._stdout = self._runner.stdout
        self._stderr = self._runner.stderr
        self._returncode = self._runner.returncode

        self.error = self._stderr

        if output:
            self.result = NmapResult(file=self.output_file, **kwargs)

            if cleanup:
                os.remove(self.output_file)
                logger.info(f'deleted {self.output_file}')

        if self._stderr:
            logger.error(msg=f'{self._stderr.decode()}')
            return False

        return True

    def scan(self, command: str, **kwargs) -> bool:
        return self.run(command=command, **kwargs)
